===================
Engineering Feature
===================

A specific type of engineering feature object is designed for each type of engineering feature.


Create engineering features
---------------------------

.. autoclass:: abaqus.EngineeringFeature.EngineeringFeature.EngineeringFeature
    :members:

Object features
---------------

Crack
~~~~~

.. autoclass:: abaqus.EngineeringFeature.Crack.Crack
    :members:

    .. autoclasstoc::

Fastener
~~~~~~~~

.. autoclass:: abaqus.EngineeringFeature.Fastener.Fastener
    :members:

    .. autoclasstoc::

Inertia
~~~~~~~

.. autoclass:: abaqus.EngineeringFeature.Inertia.Inertia
    :members:

    .. autoclasstoc::

SpringDashpot
~~~~~~~~~~~~~

.. autoclass:: abaqus.EngineeringFeature.SpringDashpot.SpringDashpot
    :members:

    .. autoclasstoc::

AssembledFastener
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.EngineeringFeature.AssembledFastener.AssembledFastener
    :members:

    .. autoclasstoc::

ContourIntegral
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.EngineeringFeature.ContourIntegral.ContourIntegral
    :members:

    .. autoclasstoc::

DebondVCCT
~~~~~~~~~~

.. autoclass:: abaqus.EngineeringFeature.DebondVCCT.DebondVCCT
    :members:

    .. autoclasstoc::

DiscreteFastener
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.EngineeringFeature.DiscreteFastener.DiscreteFastener
    :members:

    .. autoclasstoc::

EngineeringFeatureBase
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.EngineeringFeature.EngineeringFeatureBase.EngineeringFeatureBase
    :members:

    .. autoclasstoc::

HeatCapacitance
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.EngineeringFeature.HeatCapacitance.HeatCapacitance
    :members:

    .. autoclasstoc::

NonstructuralMass
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.EngineeringFeature.NonstructuralMass.NonstructuralMass
    :members:

    .. autoclasstoc::

PointFastener
~~~~~~~~~~~~~

.. autoclass:: abaqus.EngineeringFeature.PointFastener.PointFastener
    :members:

    .. autoclasstoc::

PointMassInertia
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.EngineeringFeature.PointMassInertia.PointMassInertia
    :members:

    .. autoclasstoc::

SpringDashpotToGround
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.EngineeringFeature.SpringDashpotToGround.SpringDashpotToGround
    :members:

    .. autoclasstoc::

TwoPointSpringDashpot
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.EngineeringFeature.TwoPointSpringDashpot.TwoPointSpringDashpot
    :members:

    .. autoclasstoc::

XFEMCrack
~~~~~~~~~

.. autoclass:: abaqus.EngineeringFeature.XFEMCrack.XFEMCrack
    :members:

    .. autoclasstoc::